class Temperatura:
    def __init__(self, celsius):
        self.valor = celsius

    def converter_farenheit(self):
        return self.valor * 1.8 + 32
    
    def converter_kelvin(self):
        return self.valor + 273.15
    

if __name__ == "__main__":
    celsius = float(input("Digite a temperatura em Celsius: "))
    conversor = Temperatura(celsius)
    print(f"{celsius}°C equivale a {conversor.converter_farenheit()}°F")
    print(f"{celsius}°C equivale a {conversor.converter_kelvin()}K")


class Triangulo:
    def __init__(self, a, b, c):
        self.a = a
        self.b = b
        self.c = c

    def calcular_perimetro(self):
        return self.a + self.b + self.c
    
    def calcular_area(self):
        p = self.calcular_perimetro() / 2
        return (p * (p - self.a) * (p - self.b) * (p - self.c)) ** 0.5
        

if __name__ == "__main__":
    a = float(input("Digite o valor do lado a: "))
    b = float(input("Digite o valor do lado b: "))
    c = float(input("Digite o valor do lado c: "))
    triangulo = Triangulo(a, b, c)
    print(f"O perímetro do triângulo é {triangulo.calcular_perimetro()}")
    print(f"A área do triângulo é {triangulo.calcular_area()}")


from setuptools import setup

VERSION = '0.0.29'
DESCRIPTION = 'Meu primeiro pacote em Python'
LONG_DESCRIPTION = 'Meu primeiro pacote em Python com uma descrição um pouco mais longa'

# Setting up
setup(
    name="robson_package",
    version=VERSION,
    author="Robson-tech",
    author_email="robson.junior@ufpi.edu.br",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    license="MIT",
    packages=["robson_package"],
    install_requires=[],
)